#
# spec file for package python-logutils
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           python-logutils
Version:        0.3.5
Release:        7.3
Summary:        Logging utilities
License:        BSD-3-Clause
URL:            https://logutils.readthedocs.io/
Source:         https://files.pythonhosted.org/packages/source/l/logutils/logutils-%{version}.tar.gz
Patch0:         sphinx4.patch
# PATCH-FIX-UPSTREAM logutils-pr1-fix-testasserts-py3.12.patch https://bitbucket.org/vinay.sajip/logutils/pull-requests/1
Patch1:         https://bitbucket.org/hugovk/logutils/commits/0a3af211128567c437e68261a02591ffe2682d95/raw#/logutils-pr1-fix-testasserts-py3.12.patch
# PATCH-FIX-UPSTREAM logutils-intersphinx.patch
Patch2:         logutils-intersphinx.patch
# PATCH-FIX-OPENSUSE Use logging._lock as a context manager directly
Patch3:         use-logging-lock-directly.patch
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module redis}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
BuildRequires:  python3-Sphinx
BuildRequires:  redis
BuildArch:      noarch
%python_subpackages

%description
The logutils package provides a set of handlers for the Python standard
library's logging package.

Some of these handlers are out-of-scope for the standard library, and
so they are packaged here. Others are updated versions which have
appeared in recent Python releases, but are usable with older versions
of Python and so are packaged here.

%package -n python-logutils-doc
Summary:        Documentation for %{name}
Provides:       %{python_module logutils-doc = %{version}}

%description -n python-logutils-doc
The logutils package provides a set of handlers for the Python standard
library's logging package.

Some of these handlers are out-of-scope for the standard library, and
so they are packaged here. Others are updated versions which have
appeared in recent Python releases, but are usable with older versions
of Python and so are packaged here.

This package contains the documentation.

%prep
%autosetup -p1 -n logutils-%{version}

%build
%pyproject_wheel
pushd doc
make html
rm _build/html/.buildinfo
popd

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
export PATH="$PATH:/sbin:/usr/sbin"
%pyunittest discover -v tests

%files %{python_files}
%license LICENSE.txt
%doc NEWS.txt README.rst
%{python_sitelib}/logutils
%{python_sitelib}/logutils-%{version}.dist-info

%files -n python-logutils-doc
%license LICENSE.txt
%doc doc/_build/html

%changelog
* Tue Sep 10 2024 Steve Kowalik <steven.kowalik@suse.com>
- Add patch use-logging-lock-directly.patch:
  * Use logging._lock as a context manager.
- Switch to autosetup macro.
* Thu Sep  5 2024 Christoph G <foss@grueninger.de>
- Add patch logutils-intersphinx.patch to fix compatibility
  with recent Sphinx
* Thu Jan 18 2024 Ben Greiner <code@bnavigator.de>
- Add logutils-pr1-fix-testasserts-py3.12.patch
  * https://bitbucket.org/vinay.sajip/logutils/pull-requests/1
  * Fixes the test suite. This package is really old but still
    half-maintained
- Switch to PEP517
- Deduplicate files
* Fri Feb 17 2023 Dirk Müller <dmueller@suse.com>
- update path for SLE15
* Wed Sep  1 2021 pgajdos@suse.com
- %%check: use %%pyunittest rpm macro
* Sat Jun  5 2021 Dirk Müller <dmueller@suse.com>
- add sphinx4.patch to enable build with Sphinx 4.x
* Tue Dec  4 2018 Matej Cepl <mcepl@suse.com>
- Remove superfluous devel dependency for noarch package
* Thu Jun 29 2017 tbechtold@suse.com
- update to 0.3.5:
  - Bring QueueListener implementation in line with the version in the stdlib.
  - Fixed a bug in ColorizingStreamHandler relating to encoding.
  - Return non-zero error code from "setup.py test" when a test fails.
  - Make the dictConfig tests work with both Python 2.x and 3.x.
- convert to singlespec
- fix Source url
- split -doc package
- update Url
* Thu Jul 18 2013 speilicke@suse.com
- Initial version
